//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[CommonShanten](index.md)

# CommonShanten

@Serializable

interface [CommonShanten](index.md) : [Shanten](../-shanten/index.md)

#### Inheritors

| |
|---|
| [ShantenWithoutGot](../-shanten-without-got/index.md) |
| [ShantenWithGot](../-shanten-with-got/index.md) |

## Properties

| Name | Summary |
|---|---|
| [asWithGot](../as-with-got.md) | [common]<br>val [CommonShanten](index.md).[asWithGot](../as-with-got.md): [ShantenWithGot](../-shanten-with-got/index.md) |
| [asWithoutGot](../as-without-got.md) | [common]<br>val [CommonShanten](index.md).[asWithoutGot](../as-without-got.md): [ShantenWithoutGot](../-shanten-without-got/index.md) |
| [shantenNum](../-shanten/shanten-num.md) | [common]<br>abstract val [shantenNum](../-shanten/shanten-num.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)<br>向听数 |
